/**
 * group.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const groupTypeDefs = `

# A Group.
type Group implements Node {

  # Group identifier.
  id: ID!

  # Group name.
  name: String!

  # Group description.
  description: String

  # Group code.
  code: String

  # Group's Ldap Active Directory's path.
  ldapADsPath: String

  # Group's common name.
  commonName: String

  # Group's distinguisehd name.
  distinguishedName: String

  # Group's system identifier.
  systemIdentifier: String
    
  # Is the groupsynchronized?
  isSynchronized: Boolean

  # Group's directory.
  directory: Directory

  # Group's list users.
  users (page: Page, orderBy: UserListOrder, filter: UserFilter): UserListPage!
}

# A paginated list of groups.
type GroupListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # A list of groups.
  items: [Group]
}

# A group list order.
input GroupListOrder {

  # The field to order groups by.
  field: GroupListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# A list of fields to order a group list.
enum GroupListOrderField {

  # Order groups by name.
  NAME
}

`;

module.exports = groupTypeDefs;
